@@ -216,6 +216,13 @@ class LanguageServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             async def sample_analyze_sentiment():
@@ -241,7 +248,7 @@ class LanguageServiceAsyncClient:
                 The request object. The sentiment analysis request
                 message.
             document (:class:`google.cloud.language_v1.types.Document`):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -329,6 +336,13 @@ class LanguageServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             async def sample_analyze_entities():
@@ -353,7 +367,7 @@ class LanguageServiceAsyncClient:
             request (Union[google.cloud.language_v1.types.AnalyzeEntitiesRequest, dict]):
                 The request object. The entity analysis request message.
             document (:class:`google.cloud.language_v1.types.Document`):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -439,6 +453,13 @@ class LanguageServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             async def sample_analyze_entity_sentiment():
@@ -464,7 +485,7 @@ class LanguageServiceAsyncClient:
                 The request object. The entity-level sentiment analysis
                 request message.
             document (:class:`google.cloud.language_v1.types.Document`):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -551,6 +572,13 @@ class LanguageServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             async def sample_analyze_syntax():
@@ -575,7 +603,7 @@ class LanguageServiceAsyncClient:
             request (Union[google.cloud.language_v1.types.AnalyzeSyntaxRequest, dict]):
                 The request object. The syntax analysis request message.
             document (:class:`google.cloud.language_v1.types.Document`):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -657,6 +685,13 @@ class LanguageServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             async def sample_classify_text():
@@ -682,7 +717,7 @@ class LanguageServiceAsyncClient:
                 The request object. The document classification request
                 message.
             document (:class:`google.cloud.language_v1.types.Document`):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -761,6 +796,13 @@ class LanguageServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             async def sample_annotate_text():
@@ -787,12 +829,12 @@ class LanguageServiceAsyncClient:
                 annotation API, which can perform multiple analysis
                 types (sentiment, entities, and syntax) in one call.
             document (:class:`google.cloud.language_v1.types.Document`):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             features (:class:`google.cloud.language_v1.types.AnnotateTextRequest.Features`):
-                The enabled features.
+                Required. The enabled features.
                 This corresponds to the ``features`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
