@@ -404,6 +404,7 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def analyze_sentiment(
@@ -420,6 +421,13 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             def sample_analyze_sentiment():
@@ -445,7 +453,7 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
                 The request object. The sentiment analysis request
                 message.
             document (google.cloud.language_v1.types.Document):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -523,6 +531,13 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             def sample_analyze_entities():
@@ -547,7 +562,7 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
             request (Union[google.cloud.language_v1.types.AnalyzeEntitiesRequest, dict]):
                 The request object. The entity analysis request message.
             document (google.cloud.language_v1.types.Document):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -623,6 +638,13 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             def sample_analyze_entity_sentiment():
@@ -648,7 +670,7 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
                 The request object. The entity-level sentiment analysis
                 request message.
             document (google.cloud.language_v1.types.Document):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -725,6 +747,13 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             def sample_analyze_syntax():
@@ -749,7 +778,7 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
             request (Union[google.cloud.language_v1.types.AnalyzeSyntaxRequest, dict]):
                 The request object. The syntax analysis request message.
             document (google.cloud.language_v1.types.Document):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -821,6 +850,13 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             def sample_classify_text():
@@ -846,7 +882,7 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
                 The request object. The document classification request
                 message.
             document (google.cloud.language_v1.types.Document):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -915,6 +951,13 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import language_v1
 
             def sample_annotate_text():
@@ -941,12 +984,12 @@ class LanguageServiceClient(metaclass=LanguageServiceClientMeta):
                 annotation API, which can perform multiple analysis
                 types (sentiment, entities, and syntax) in one call.
             document (google.cloud.language_v1.types.Document):
-                Input document.
+                Required. Input document.
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             features (google.cloud.language_v1.types.AnnotateTextRequest.Features):
-                The enabled features.
+                Required. The enabled features.
                 This corresponds to the ``features`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
