@@ -103,6 +103,7 @@ class LanguageServiceGrpcAsyncIOTransport(LanguageServiceTransport):
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -198,6 +199,7 @@ class LanguageServiceGrpcAsyncIOTransport(LanguageServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -333,7 +335,7 @@ class LanguageServiceGrpcAsyncIOTransport(LanguageServiceTransport):
         r"""Return a callable for the analyze syntax method over gRPC.
 
         Analyzes the syntax of the text and provides sentence
-        boundaries and tokenization along with part-of-speech
+        boundaries and tokenization along with part of speech
         tags, dependency trees, and other properties.
 
         Returns:
